import GuildBlock from './blocks/GuildBlock';
import Websocket from './websocket/Websocket';
export default class Client {
    token: string;
    ws: Websocket;
    guilds: GuildBlock;
    options: {
        intents: never;
        debug: boolean;
    };
    private events;
    constructor(options?: any);
    /**
     * Add an event listener.
     *
     * @param {string} event The event name.
     * @param {Function} listener The function to call when the event is emitted.
     * @returns {void}
     */
    on(event: string, callback: Function): void;
    /**
     * Undind an event listener.
     *
     * @param {string} event The event name to unbind.
     * @returns {void}
     */
    unbind(event: string): void;
    /**
     * Emit an event.
     *
     * @param {string} event The event name.
     * @param {any} data The event data to pass to the listener.
     * @returns {void}
     */
    emit(event: string, ...args: any[]): void;
    /**
     * Connect to the Discord gateway.
     *
     * @param {string} token Your bot's token.
     * @returns {void}
     */
    connect(token: string): void;
    /**
     * Emit a log in debug mode.
     *
     * @param {any} message The log message.
     * @returns {void}
     */
    debug(...message: any[]): void;
    /**
     * Emit a warning in debug mode.
     *
     * @param {any} message The warning message.
     * @returns {void}
     */
    warn(...message: any[]): void;
}
