"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const GuildError_1 = __importDefault(require("../errors/GuildError"));
const Role_1 = __importDefault(require("./Role"));
class Guild {
    constructor(client, data) {
        this.client = null;
        this.id = null;
        this.name = null;
        this.icon = null;
        this.nsfw = false;
        this.discoverySplash = null;
        this.banner = null;
        this.description = null;
        this.verificationLevel = null;
        this.defaultNotifications = null;
        this.available = true;
        this.systemChannelId = null;
        this.ownerId = null;
        this.large = false;
        this.afkChannelId = null;
        this.explicitContentFilter = null;
        this.maxMembers = null;
        this.preferredLocale = null;
        this.mfaLevel = null;
        this.vanityCode = null;
        this.nsfwLevel = null;
        this.maxVideoChannelUsers = null;
        this.boosterCount = null;
        this.splash = null;
        this.memberCount = null;
        this.boostTier = null;
        this.rulesChannelId = null;
        this.afkTimeout = null;
        this.roles = [];
        if (typeof data.id !== 'string') {
            throw new GuildError_1.default('invalid guild data provided');
        }
        this.client = client;
        this.id = data.id;
        this._build(data);
    }
    _build(data) {
        if ('name' in data) {
            this.name = data.name;
        }
        if ('icon' in data) {
            this.icon = data.icon;
        }
        if ('nsfw' in data) {
            this.nsfw = data.nsfw;
        }
        if ('discovery_splash' in data) {
            this.discoverySplash = data.discovery_splash;
        }
        if ('banner' in data) {
            this.banner = data.banner;
        }
        if ('description' in data) {
            this.description = data.description;
        }
        if ('verification_level' in data) {
            this.verificationLevel = data.verification_level;
        }
        if ('unavailable' in data) {
            this.available = !data.unavailable;
        }
        if ('system_channel_id' in data) {
            this.systemChannelId = data.system_channel_id;
        }
        if ('owner_id' in data) {
            this.ownerId = data.owner_id;
        }
        if ('large' in data) {
            this.large = data.large;
        }
        if ('afk_channel_id' in data) {
            this.afkChannelId = data.afk_channel_id;
        }
        if ('explicit_content_filter' in data) {
            this.explicitContentFilter = data.explicit_content_filter;
        }
        if ('max_members' in data) {
            this.maxMembers = data.max_members;
        }
        if ('preferred_locale' in data) {
            this.preferredLocale = data.preferred_locale;
        }
        if ('mfa_level' in data) {
            this.mfaLevel = data.mfa_level;
        }
        if ('system_channel_flags' in data) {
            this.systemChannelId = data.system_channel_flags;
        }
        if ('vanity_url_code' in data) {
            this.vanityCode = data.vanity_url_code;
        }
        if ('nsfw_level' in data) {
            this.nsfwLevel = data.nsfw_level;
        }
        if ('max_video_channel_users' in data) {
            this.maxVideoChannelUsers = data.max_video_channel_users;
        }
        if ('premium_subscription_count' in data) {
            this.boosterCount = data.premium_subscription_count;
        }
        if ('member_count' in data) {
            this.memberCount = data.member_count;
        }
        if ('splash' in data) {
            this.splash = data.splash;
        }
        if ('premium_tier' in data) {
            this.boostTier = data.premium_tier;
        }
        if ('rules_channel_id' in data) {
            this.rulesChannelId = data.rules_channel_id;
        }
        if ('afk_timeout' in data) {
            this.afkTimeout = data.afk_timeout;
        }
        if ('roles' in data) {
            this.roles = data.roles.map((r) => new Role_1.default(this.client, r));
        }
    }
}
exports.default = Guild;
