"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Guild_1 = __importDefault(require("../Guild"));
const Cache_1 = __importDefault(require("../Cache"));
const HTTPGuild_1 = __importDefault(require("../http/HTTPGuild"));
class GuildBlock {
    constructor(client, options) {
        this.client = null;
        this.cache = null;
        this.client = client;
        this.cache = new Cache_1.default(options);
    }
    fetch(options) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof options === 'string') {
                options = {
                    guild: options,
                    shouldCache: true,
                    bypassCache: false,
                };
            }
            else if (options instanceof Guild_1.default) {
                options = {
                    guild: options.id,
                    shouldCache: true,
                    bypassCache: false,
                };
            }
            else {
                options.shouldCache = (_a = options.shouldCache) !== null && _a !== void 0 ? _a : true;
                options.bypassCache = (_b = options.bypassCache) !== null && _b !== void 0 ? _b : false;
                if (options.guild instanceof Guild_1.default) {
                    options.guild = options.guild.id;
                }
                else {
                    options.guild = options.guild;
                }
            }
            if (!options.bypassCache) {
                const cached = this.cache.get(options.guild);
                if (cached) {
                    return cached;
                }
            }
            let guild = yield HTTPGuild_1.default.get(this.client, options.guild);
            guild = new Guild_1.default(this.client, guild);
            if (options.shouldCache) {
                this.cache.set(guild.id, guild);
            }
            return guild;
        });
    }
}
exports.default = GuildBlock;
